#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# Author: Michael Dvorak - specialis IT GmbH
# Version: 1.0 - 2021-12-23

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Age,
    Alternative,
    CascadingDropdown,
    Checkbox,
    Dictionary,
    DropdownChoice,
    Filesize,
    FixedValue,
    Integer,
    ListOf,
    ListOfStrings,
    RegExp,
    RegExpUnicode,
    TextAscii,
    TextUnicode,
    Transform,
    Tuple,
)
from cmk.gui.plugins.wato import (
    CheckParameterRulespecWithoutItem,
    RulespecGroupCheckParametersApplications,
    rulespec_registry,
)
    
def _parameter_valuespec_username():
    return Dictionary(
        title=_('RDSH active user'),
        elements=[
            ("user_patterns",
             ListOf(
                TextAscii(
                   title=_("Username"),
                   size=40,
                ),
                title=_("Define usernames that must be online"),
                help=
                _('<p>You can define one or several usernames that must be online!</p>'),
                add_label=_("Add username"),
             )),   
        ],
    )
    
rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="spit_rdsh_user",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_username,
        title=lambda: _("RDSH active user"),
    ))