#####################################################################################################################
#  ScriptName: spit_rdsh_user.ps1
#
#  Description:
#  This plugin gets all TS Sessions of the local host. This plugin needs the powershell module PSTerminalServices to
#  be installed on the local machine -> see https://www.powershellgallery.com/packages/PSTerminalServices/1.0
#  NOTE: Don't forget the adjust the path to the PSTerminalServices PowerShell module
#
#  Author: Dvorak Michael - specialis IT GmbH
#####################################################################################################################
#  Version History
#  1.0 - 2021-12-23 - initial Release
#  1.1 - 2022-03-17 - Bugfix - check crashed if client name contained a white space
#####################################################################################################################

# IMPORTANT - set the correct path for PSTerminalServices!!
Import-Module C:\Users\Administrator\Documents\WindowsPowerShell\Modules\PSTerminalServices

$tsSessions = Get-TSSession -Filter {$_.UserName -ne ''} | select-object -property ("UserName", "State", "ConnectionState", "ClientName", "ClientIPAddress", "LastInputTime", "CurrentTime", "LoginTime")

Write-Output "<<<spit_rdsh_user>>>"

foreach ($tsSession in $tsSessions) { 

    $idle = ""
    $curr = get-date $tsSession.CurrentTime
    $last = get-date $tsSession.LastInputTime
    $idleTime = $curr - $last
    
    if ($idleTime.Days -eq 0 -and $idleTime.Hours -eq 0 -and $idleTime.Minutes -eq 0) {
    
        $idle = "."
        
    } else {
    
        if ($idleTime.Days -ne 0) { $idle = $idle + $idleTime.Days + "*" }
        $idle = $idle + $idleTime.Hours + ":" + $idleTime.Minutes
    }
    
    $user = $tsSession.UserName
    $state = $tsSession.ConnectionState
    $loginTime = get-date $tsSession.LoginTime -f "yyyyMMddHHmm"
    
    if ($tsSession.ConnectionState -eq "Disconnected") {

        $clientName = "none"
        $ipAddress = "none"

    } else {

        $clientName = ($tsSession.ClientName).replace(' ','-')
        $ipAddress = $tsSession.ClientIPAddress.IPAddressToString
    }
    
    if (!$ipAddress) { $ipAddress= "none" }
    if (!$clientName) { $clientName = "none" }

    Write-Output "$user $state $loginTime $clientName $ipAddress"
}
